==> update%20from%201.1.0%20to%201.2.0.zip: app/Views/backend/admin/pages/partners.php <==
<div class="main-content">
    <section class="section">
        <div class="section-header">
            <h1><?= labels('providers', "Providers") ?></h1>
            <div class="section-header-breadcrumb">
                <div class="breadcrumb-item active"><a href="<?= base_url('/admin/dashboard') ?>">Dashboard</a></div>
                <div class="breadcrumb-item">Providers</a></div>
            </div>
        </div>
        <div class="container-fluid card">
            <div class="align-items-center bg-navy card-header d-flex justify-content-between">
                <div class="bg-navy">
                    <h4><?= labels('all_providers', "All Providers") ?></h4>
                </div>
                <div>
                    <a href="<?= base_url("admin/partners/add_partner"); ?>" class="btn btn-primary"><i class="fa fa-user-plus"></i> Add Provider</a>
                </div>
            </div>
            <div class="row mb-3">
                <div class="col-lg">
                    <table class="table table-striped" id="partner_list" data-detail-view="true" data-detail-formatter="user_formater" data-auto-refresh="true" data-toggle="table" data-url="<?= base_url("admin/partners/list") ?>" data-side-pagination="server" data-pagination="true" data-page-list="[5, 10, 25, 50, 100, 200, All]" data-search="true" data-show-columns="true" data-show-columns-search="true" data-show-refresh="true" data-sort-name="id" data-sort-order="desc">
                        <thead>
                            <tr>
                                <th data-field="id" data-visible="false" class="text-center" data-sortable="true"><?= labels('id', 'ID') ?></th>
                                <th data-field="partner_id" class="text-center" data-visible="false" data-sortable="false"><?= labels('provider_id', 'Provider Id') ?></th>
                                <th data-field="partner_profile" class="text-center"><?= labels('profile', 'Provider Profile') ?></th>
                                <th data-field="partner_name" class="text-center" data-visible="false" data-sortable="true"><?= labels('provider_name', 'Provider Name') ?></th>
                                <th data-field="company_name" class="text-center" data-sortable="true" data-sortable="true"><?= labels('company_name', 'Company Name') ?></th>
                                <th data-field="mobile" class="text-center" data-sortable="true" data-sortable="true"><?= labels('mobile', 'Mobile') ?></th>
                                <th data-field="national_id" class="text-center" data-visible="false" data-sortable="true"><?= labels('national_id', 'National Id') ?></th>
                                <th data-field="balance" class="text-center" data-visible="false" data-sortable="true"><?= labels('balance', 'Balance') ?></th>
                                <th data-field="address_id" class="text-center" data-visible="false" data-sortable="true"><?= labels('address_id', 'Address Id') ?></th>
                                <th data-field="address" class="text-center" data-visible="false" data-sortable="false"><?= labels('address', 'Address') ?></th>
                                <th data-field="passport" class="text-center" data-visible="false" data-sortable="false"><?= labels('passport', 'Passport') ?></th>
                                <th data-field="tax_name" class="text-center" data-visible="false" data-sortable="false"><?= labels('tax_name', 'Tax Name') ?></th>
                                <th data-field="tax_number" class="text-center" data-visible="false" data-sortable="false"><?= labels('tax_number', 'Tax Number') ?></th>
                                <th data-field="bank_name" class="text-center" data-sortable="false" data-visible="false"><?= labels('bank_name', 'Bank Name') ?></th>
                                <th data-field="account_number" class="text-center" data-sortable="false" data-visible="false"><?= labels('account_number', 'Account Number') ?></th>
                                <th data-field="account_name" class="text-center" data-sortable="false" data-visible="false"><?= labels('account_name', 'Account Name') ?></th>
                                <th data-field="bank_code" class="text-center" data-sortable="false" data-visible="false"><?= labels('bank_code', 'Bank Code') ?></th>
                                <!--  -->
                                <th data-field="stars" class="text-center" data-sortable="false" data-visible="true"><?= labels('stars', 'Stars') ?></th>
                                <!--  -->
                                <th data-field="swift_code" class="text-center" data-visible="false" data-sortable="false"><?= labels('swift_code', 'Swift Code') ?></th>
                                <th data-field="advance_booking_details" class="text-center" data-visible="false" data-sortable="false"><?= labels('advance_booking_details', 'Advance Booking Details') ?></th>
                                <th data-field="type" class="text-center" data-sortable="true"><?= labels('type', 'Type') ?></th>
                                <th data-field="number_of_members" class="text-center" data-sortable="false" data-visible="false"><?= labels('number_of_members', 'Number Of Members') ?></th>
                                <th data-field="admin_commissions" class="text-center" data-visible="false" data-sortable="false"><?= labels('admin_commissions', 'Admin Commision') ?></th>
                                <th data-field="ratings" class="text-center" data-visible="false" data-sortable="false"><?= labels('ratings', 'Rating') ?></th>
                                <th data-field="number_of_ratings" class="text-center" data-sortable="true" data-visible="false"><?= labels('number_of_ratings', 'Number Of Rating') ?></th>

                                <th data-field="status" class="text-center" data-sortable="false"><?= labels('status', 'Status') ?></th>

                                <th data-field="created_at" class="text-center" data-sortable="false"><?= labels('created_at', 'Created At') ?></th>
                                <th data-field="is_approved" class="text-center" data-sortable="false" data-events="partner_events"><?= labels('is_approved', 'Is Approved') ?></th>
                            </tr>
                        </thead>
                    </table>
                </div>
            </div>
        </div>
    </section>
</div>

<!-- model for view rating -->

<div class="modal fade" id="view_rating_model" tabindex="-1" role="dialog" aria-labelledby="view_rating_model" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered modal-xl" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLongTitle">Provider Ratings</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>

            <div class="modal-body">
                <div class="row ">
                    <div class="col-md">
                        <div class="table-responsive mb-3">
                            <table class="table table-striped" id="rating_table" data-detail-view="true" data-detail-formatter="user_formater" data-auto-refresh="true" data-toggle="table" data-url="" data-side-pagination="server" data-pagination="true" data-page-list="[5, 10, 25, 50, 100, 200, All]" data-search="true" data-show-columns="true" data-show-columns-search="true" data-show-refresh="true" data-sort-name="id" data-sort-order="desc">
                                <thead>
                                    <tr>
                                        <th data-field="id"><?= labels('id', 'ID') ?></th>
                                        <th data-field="user_name"><?= labels('user_name', 'USer Name') ?></th>
                                        <th data-field="service_id"><?= labels('service_id', 'Service ID') ?></th>
                                        <th data-field="stars"><?= labels('rating', 'Rating') ?></th>
                                        <th data-field="images"><?= labels('images', 'Images') ?></th>
                                        <th data-field="comment"><?= labels('comment', 'Comment') ?></th>
                                        <th data-field="created_at"><?= labels('date_of_rating', 'Date of Rating') ?></th>
                                        <!-- <th data-field="operations" data-events="rating_event"> <?= labels('operations', 'Operations') ?> </th> -->
                                    </tr>
                                </thead>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                <button type="button" class="btn btn-primary">Save changes</button>
            </div>
        </div>
    </div>
</div>

==> update%20from%201.2.0%20to%201.3.0.zip: app/Views/backend/admin/pages/partners.php <==
<div class="main-content">
    <section class="section">
        <div class="section-header">
            <h1><?= labels('providers', "Providers") ?></h1>
            <div class="section-header-breadcrumb">
                <div class="breadcrumb-item active"><a href="<?= base_url('/admin/dashboard') ?>"><i class="fas fa-home-alt text-primary"></i> <?= labels('Dashboard', 'Dashboard') ?></a></div>
                <div class="breadcrumb-item"><i class="fas fa-handshake text-warning"></i> <?= labels('providers', 'Provider') ?></a></div>
            </div>
        </div>
        <div class="container-fluid card">
            <div class="align-items-center bg-navy card-header d-flex justify-content-between">
                <div class="bg-navy">
                    <h4><?= labels('all_providers', "All Providers") ?></h4>
                </div>
                <div>
                    <a href="<?= base_url("admin/partners/add_partner"); ?>" class="btn btn-primary"><i class="fa fa-user-plus"></i>  <?= labels('providers', 'Add Provider') ?></a>
                </div>
            </div>
            <div class="row mb-3">
                <div class="col-lg">
                    <table class="table table-striped" id="partner_list"  data-detail-formatter="user_formater" data-auto-refresh="true" data-toggle="table" data-url="<?= base_url("admin/partners/list") ?>" data-side-pagination="server" data-pagination="true" data-page-list="[5, 10, 25, 50, 100, 200, All]" data-search="true" data-show-columns="true" data-show-columns-search="true" data-show-refresh="true" data-sort-name="id" data-sort-order="desc">
                        <thead>
                            <tr>
                                <th data-field="id" data-visible="false" class="text-center" data-sortable="true"><?= labels('id', 'ID') ?></th>
                                <th data-field="partner_id" class="text-center" data-visible="false" data-sortable="false"><?= labels('provider_id', 'Provider Id') ?></th>
                                <th data-field="partner_profile" class="text-center"><?= labels('profile', 'Provider Profile') ?></th>
                                <th data-field="partner_name" class="text-center" data-visible="false" data-sortable="true"><?= labels('provider_name', 'Provider Name') ?></th>
                                <th data-field="company_name" class="text-center" data-sortable="true" data-sortable="true"><?= labels('company_name', 'Company Name') ?></th>
                                <th data-field="mobile" class="text-center"><?= labels('mobile', 'Mobile') ?></th>
                                <th data-field="national_id" class="text-center" data-visible="false" data-sortable="true"><?= labels('national_id', 'National Id') ?></th>
                                <th data-field="balance" class="text-center" data-visible="false" data-sortable="true"><?= labels('balance', 'Balance') ?></th>
                                <th data-field="address_id" class="text-center" data-visible="false" data-sortable="true"><?= labels('address_id', 'Address Id') ?></th>
                                <th data-field="address" class="text-center" data-visible="false" data-sortable="false"><?= labels('address', 'Address') ?></th>
                                <th data-field="passport" class="text-center" data-visible="false" data-sortable="false"><?= labels('passport', 'Passport') ?></th>
                                <th data-field="tax_name" class="text-center" data-visible="false" data-sortable="false"><?= labels('tax_name', 'Tax Name') ?></th>
                                <th data-field="tax_number" class="text-center" data-visible="false" data-sortable="false"><?= labels('tax_number', 'Tax Number') ?></th>
                                <th data-field="bank_name" class="text-center" data-sortable="false" data-visible="false"><?= labels('bank_name', 'Bank Name') ?></th>
                                <th data-field="account_number" class="text-center" data-sortable="false" data-visible="false"><?= labels('account_number', 'Account Number') ?></th>
                                <th data-field="account_name" class="text-center" data-sortable="false" data-visible="false"><?= labels('account_name', 'Account Name') ?></th>
                                <th data-field="bank_code" class="text-center" data-sortable="false" data-visible="false"><?= labels('bank_code', 'Bank Code') ?></th>
                                <!--  -->
                                <th data-field="stars" class="text-center" data-sortable="false" data-visible="true"><?= labels('stars', 'Stars') ?></th>
                                <!--  -->
                                <th data-field="swift_code" class="text-center" data-visible="false" data-sortable="false"><?= labels('swift_code', 'Swift Code') ?></th>
                                <th data-field="advance_booking_details" class="text-center" data-visible="false" data-sortable="false"><?= labels('advance_booking_details', 'Advance Booking Details') ?></th>
                                <th data-field="type" class="text-center" data-sortable="true"><?= labels('type', 'Type') ?></th>
                                <th data-field="number_of_members" class="text-center" data-sortable="false" data-visible="false"><?= labels('number_Of_members', 'Number Of Members') ?></th>
                                <th data-field="admin_commissions" class="text-center" data-visible="false" data-sortable="false"><?= labels('admin_commissions', 'Admin Commision') ?></th>
                                <th data-field="ratings" class="text-center" data-visible="false" data-sortable="false"><?= labels('rating', 'Rating') ?></th>
                                <th data-field="number_of_ratings" class="text-center" data-sortable="true" data-visible="false"><?= labels('number_Of_rating', 'Number Of Rating') ?></th>

                                <th data-field="status" class="text-center" data-sortable="false"><?= labels('status', 'Status') ?></th>

                                <th data-field="created_at" class="text-center" data-sortable="false"><?= labels('created_at', 'Created At') ?></th>
                                <th data-field="is_approved" class="text-center" data-sortable="false" data-events="partner_events"><?= labels('is_Approved', 'Is Approved') ?></th>
                            </tr>
                        </thead>
                    </table>
                </div>
            </div>
        </div>
    </section>
</div>

<!-- model for view rating -->

<div class="modal fade" id="view_rating_model" tabindex="-1" role="dialog" aria-labelledby="view_rating_model" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered modal-xl" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="exampleModalLongTitle"><?= labels('provider_ratings', 'Provider Ratings') ?></h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>

            <div class="modal-body">
                <div class="row ">
                    <div class="col-md">
                        <div class="table-responsive mb-3">
                            <table class="table table-striped" id="rating_table" data-detail-view="true" data-detail-formatter="user_formater" data-auto-refresh="true" data-toggle="table" data-url="" data-side-pagination="server" data-pagination="true" data-page-list="[5, 10, 25, 50, 100, 200, All]" data-search="true" data-show-columns="true" data-show-columns-search="true" data-show-refresh="true" data-sort-name="id" data-sort-order="desc">
                                <thead>
                                    <tr>
                                        <th data-field="id"><?= labels('id', 'ID') ?></th>
                                        <th data-field="user_name"><?= labels('user_name', 'USer Name') ?></th>
                                        <th data-field="service_id"><?= labels('service_id', 'Service ID') ?></th>
                                        <th data-field="stars"><?= labels('rating', 'Rating') ?></th>
                                        <th data-field="images"><?= labels('images', 'Images') ?></th>
                                        <th data-field="comment"><?= labels('comment', 'Comment') ?></th>
                                        <th data-field="created_at"><?= labels('date_of_rating', 'Date of Rating') ?></th>
                                        <!-- <th data-field="operations" data-events="rating_event"> <?= labels('operations', 'Operations') ?> </th> -->
                                    </tr>
                                </thead>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal"> <?= labels('close', 'Close') ?> </button>
                <button type="button" class="btn btn-primary"> <?= labels('save_changes', 'Close') ?></button>
            </div>
        </div>
    </div>
</div>
